@@ -112,7 +112,6 @@ OC.L10N.register(
     "Personal info" : "Personal info",
     "Mobile & desktop" : "Mobile & desktop",
     "Email server" : "Email server",
-    "Security & setup warnings" : "Security & setup warnings",
     "Background jobs" : "Background jobs",
     "Unlimited" : "Unlimited",
     "Verifying" : "Verifying",
@@ -136,8 +135,6 @@ OC.L10N.register(
     "Email test" : "Email test",
     "Email test was successfully sent" : "Email test was successfully sent",
     "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings.",
-    "File locking" : "File locking",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems.",
     "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "The database is used for transactional file locking. To enhance performance, please configure memcache, if available.",
     "Forwarded for headers" : "Forwarded for headers",
     "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "Your \"trusted_proxies\" setting is not correctly set, it should be an array.",
@@ -245,7 +242,6 @@ OC.L10N.register(
     "Show details for {appName} app" : "Show details for {appName} app",
     "Update to {update}" : "Update to {update}",
     "Remove" : "Remove",
-    "Disable" : "Disable",
     "Featured" : "Featured",
     "This app is supported via your current Nextcloud subscription." : "This app is supported via your current Nextcloud subscription.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Featured apps are developed by and within the community. They offer central functionality and are ready for production use.",
@@ -262,6 +258,7 @@ OC.L10N.register(
     "_%n app has an update available_::_%n apps have an update available_" : ["%n app has an update available","%n apps have an update available"],
     "_Update_::_Update all_" : ["Update","Update all"],
     "Loading" : "Loading",
+    "Type" : "Type",
     "Description" : "Description",
     "Details" : "Details",
     "All" : "All",
@@ -373,8 +370,6 @@ OC.L10N.register(
     "Error removing profile picture" : "Error removing profile picture",
     "Your biography" : "Your biography",
     "You are a member of the following groups:" : "You are a member of the following groups:",
-    "You are using <strong>{usage}</strong>" : "You are using <strong>{usage}</strong>",
-    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Your full name" : "Your full name",
     "Primary email for password reset and notifications" : "Primary email for password reset and notifications",
     "Email options" : "Email options",
@@ -494,12 +489,12 @@ OC.L10N.register(
     "About" : "About",
     "Full name" : "Full name",
     "Additional email" : "Additional email",
+    "Fediverse (e.g. Mastodon)" : "Fediverse (e.g. Mastodon)",
     "Headline" : "Headline",
     "Organisation" : "Organisation",
     "Phone number" : "Phone number",
     "Role" : "Role",
     "X (formerly Twitter)" : "X (formerly Twitter)",
-    "Fediverse (e.g. Mastodon)" : "Fediverse (e.g. Mastodon)",
     "Website" : "Website",
     "Profile visibility" : "Profile visibility",
     "Locale" : "Locale",
@@ -514,13 +509,14 @@ OC.L10N.register(
     "Show to everyone" : "Show to everyone",
     "Hide" : "Hide",
     "Download and enable" : "Download and enable",
+    "Disable" : "Disable",
     "Allow untested app" : "Allow untested app",
     "The app will be downloaded from the App Store" : "The app will be downloaded from the App Store",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected.",
     "Never" : "Never",
     "An error occurred during the request. Unable to proceed." : "An error occurred during the request. Unable to proceed.",
-    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Error: This app cannot be enabled because it makes the server unstable",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds.",
     "Do you really want to wipe your data from this device?" : "Do you really want to wipe your data from this device?",
     "Confirm wipe" : "Confirm wipe",
     "Could not delete the app token" : "Could not delete the app token",
@@ -551,6 +547,7 @@ OC.L10N.register(
     "SMTP Password" : "SMTP Password",
     "Save" : "Save",
     "Test and verify email settings" : "Test and verify email settings",
+    "Security & setup warnings" : "Security & setup warnings",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information.",
     "All checks passed." : "All checks passed.",
     "There are some errors regarding your setup." : "There are some errors regarding your setup.",
@@ -561,7 +558,6 @@ OC.L10N.register(
     "Reasons to use Nextcloud in your organization" : "Reasons to use Nextcloud in your organization",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Like our Facebook page",
-    "Follow us on Twitter" : "Follow us on Twitter",
     "Follow us on Mastodon" : "Follow us on Mastodon",
     "Check out our blog" : "Check out our blog",
     "Subscribe to our newsletter" : "Subscribe to our newsletter",
@@ -580,6 +576,8 @@ OC.L10N.register(
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below.",
     "Missing optional index \"%s\" in table \"%s\"." : "Missing optional index \"%s\" in table \"%s\".",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster.",
+    "File locking" : "File locking",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems.",
     "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible.",
     "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher.",
     "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher.",
@@ -601,6 +599,8 @@ OC.L10N.register(
     "The cron.php needs to be executed by the system user \"{user}\"." : "The cron.php needs to be executed by the system user \"{user}\".",
     "Enable or disable profile by default for new users." : "Enable or disable profile by default for new users.",
     "You are about to remove the group \"{group}\". The users will NOT be deleted." : "You are about to remove the group \"{group}\". The users will NOT be deleted.",
+    "You are using <strong>{usage}</strong>" : "You are using <strong>{usage}</strong>",
+    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
     "Additional emails" : "Additional emails",
     "Enable Profile" : "Enable Profile",
     "No users" : "No users",
@@ -644,6 +644,7 @@ OC.L10N.register(
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions",
     "Show to logged in users only" : "Show to logged in users only",
     "Nextcloud help resources" : "Nextcloud help resources",
-    "SMTP Username" : "SMTP Username"
+    "SMTP Username" : "SMTP Username",
+    "Follow us on Twitter" : "Follow us on Twitter"
 },
 "nplurals=2; plural=(n!=1);");
