@@ -1,39 +1,19 @@
 <?php
-/**
- * @copyright Copyright (c) 2016, ownCloud, Inc.
- *
- * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
- * @author Joas Schilling <coding@schilljs.com>
- * @author Morris Jobke <hey@morrisjobke.de>
- * @author Roeland Jago Douma <roeland@famdouma.nl>
- * @author Roger Szabo <roger.szabo@web.de>
- * @author Vinicius Cubas Brand <vinicius@eita.org.br>
- *
- * @license AGPL-3.0
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
- *
- */
 
+/**
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2016 ownCloud, Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
+ */
 namespace OCA\User_LDAP\Jobs;
 
-use OC\BackgroundJob\TimedJob;
 use OCA\User_LDAP\Helper;
-use OCA\User_LDAP\LDAP;
 use OCA\User_LDAP\Mapping\UserMapping;
+use OCA\User_LDAP\User\DeletedUsersIndex;
 use OCA\User_LDAP\User_LDAP;
 use OCA\User_LDAP\User_Proxy;
-use OCA\User_LDAP\User\DeletedUsersIndex;
+use OCP\AppFramework\Utility\ITimeFactory;
+use OCP\BackgroundJob\TimedJob;
 
 /**
  * Class CleanUp
@@ -43,7 +23,7 @@ use OCA\User_LDAP\User\DeletedUsersIndex;
  * @package OCA\User_LDAP\Jobs;
  */
 class CleanUp extends TimedJob {
-	/** @var int $limit amount of users that should be checked per run */
+	/** @var ?int $limit amount of users that should be checked per run */
 	protected $limit;
 
 	/** @var int $defaultIntervalMin default interval in minutes */
@@ -67,64 +47,59 @@ class CleanUp extends TimedJob {
 	/** @var DeletedUsersIndex */
 	protected $dui;
 
-	public function __construct() {
+	public function __construct(
+		ITimeFactory $timeFactory,
+		User_Proxy $userBackend,
+		DeletedUsersIndex $dui
+	) {
+		parent::__construct($timeFactory);
 		$minutes = \OC::$server->getConfig()->getSystemValue(
 			'ldapUserCleanupInterval', (string)$this->defaultIntervalMin);
 		$this->setInterval((int)$minutes * 60);
+		$this->userBackend = $userBackend;
+		$this->dui = $dui;
 	}
 
 	/**
 	 * assigns the instances passed to run() to the class properties
 	 * @param array $arguments
 	 */
-	public function setArguments($arguments) {
+	public function setArguments($arguments): void {
 		//Dependency Injection is not possible, because the constructor will
 		//only get values that are serialized to JSON. I.e. whatever we would
 		//pass in app.php we do add here, except something else is passed e.g.
 		//in tests.
 
-		if(isset($arguments['helper'])) {
+		if (isset($arguments['helper'])) {
 			$this->ldapHelper = $arguments['helper'];
 		} else {
-			$this->ldapHelper = new Helper(\OC::$server->getConfig());
+			$this->ldapHelper = new Helper(\OC::$server->getConfig(), \OC::$server->getDatabaseConnection());
 		}
 
-		if(isset($arguments['ocConfig'])) {
+		if (isset($arguments['ocConfig'])) {
 			$this->ocConfig = $arguments['ocConfig'];
 		} else {
 			$this->ocConfig = \OC::$server->getConfig();
 		}
 
-		if(isset($arguments['userBackend'])) {
+		if (isset($arguments['userBackend'])) {
 			$this->userBackend = $arguments['userBackend'];
-		} else {
-			$this->userBackend =  new User_Proxy(
-				$this->ldapHelper->getServerConfigurationPrefixes(true),
-				new LDAP(),
-				$this->ocConfig,
-				\OC::$server->getNotificationManager(),
-				\OC::$server->getUserSession(),
-				\OC::$server->query('LDAPUserPluginManager')
-			);
 		}
 
-		if(isset($arguments['db'])) {
+		if (isset($arguments['db'])) {
 			$this->db = $arguments['db'];
 		} else {
 			$this->db = \OC::$server->getDatabaseConnection();
 		}
 
-		if(isset($arguments['mapping'])) {
+		if (isset($arguments['mapping'])) {
 			$this->mapping = $arguments['mapping'];
 		} else {
-			$this->mapping = new UserMapping($this->db);
+			$this->mapping = \OCP\Server::get(UserMapping::class);
 		}
 
-		if(isset($arguments['deletedUsersIndex'])) {
+		if (isset($arguments['deletedUsersIndex'])) {
 			$this->dui = $arguments['deletedUsersIndex'];
-		} else {
-			$this->dui = new DeletedUsersIndex(
-				$this->ocConfig, $this->db, $this->mapping);
 		}
 	}
 
@@ -132,19 +107,13 @@ class CleanUp extends TimedJob {
 	 * makes the background job do its work
 	 * @param array $argument
 	 */
-	public function run($argument) {
+	public function run($argument): void {
 		$this->setArguments($argument);
 
-		if(!$this->isCleanUpAllowed()) {
+		if (!$this->isCleanUpAllowed()) {
 			return;
 		}
 		$users = $this->mapping->getList($this->getOffset(), $this->getChunkSize());
-		if(!is_array($users)) {
-			//something wrong? Let's start from the beginning next time and
-			//abort
-			$this->setOffset(true);
-			return;
-		}
 		$resetOffset = $this->isOffsetResetNecessary(count($users));
 		$this->checkUsers($users);
 		$this->setOffset($resetOffset);
@@ -152,20 +121,17 @@ class CleanUp extends TimedJob {
 
 	/**
 	 * checks whether next run should start at 0 again
-	 * @param int $resultCount
-	 * @return bool
 	 */
-	public function isOffsetResetNecessary($resultCount) {
+	public function isOffsetResetNecessary(int $resultCount): bool {
 		return $resultCount < $this->getChunkSize();
 	}
 
 	/**
 	 * checks whether cleaning up LDAP users is allowed
-	 * @return bool
 	 */
-	public function isCleanUpAllowed() {
+	public function isCleanUpAllowed(): bool {
 		try {
-			if($this->ldapHelper->haveDisabledConfigurations()) {
+			if ($this->ldapHelper->haveDisabledConfigurations()) {
 				return false;
 			}
 		} catch (\Exception $e) {
@@ -177,9 +143,8 @@ class CleanUp extends TimedJob {
 
 	/**
 	 * checks whether clean up is enabled by configuration
-	 * @return bool
 	 */
-	private function isCleanUpEnabled() {
+	private function isCleanUpEnabled(): bool {
 		return (bool)$this->ocConfig->getSystemValue(
 			'ldapUserCleanupInterval', (string)$this->defaultIntervalMin);
 	}
@@ -188,8 +153,8 @@ class CleanUp extends TimedJob {
 	 * checks users whether they are still existing
 	 * @param array $users result from getMappedUsers()
 	 */
-	private function checkUsers(array $users) {
-		foreach($users as $user) {
+	private function checkUsers(array $users): void {
+		foreach ($users as $user) {
 			$this->checkUser($user);
 		}
 	}
@@ -198,8 +163,8 @@ class CleanUp extends TimedJob {
 	 * checks whether a user is still existing in LDAP
 	 * @param string[] $user
 	 */
-	private function checkUser(array $user) {
-		if($this->userBackend->userExistsOnLDAP($user['name'])) {
+	private function checkUser(array $user): void {
+		if ($this->userBackend->userExistsOnLDAP($user['name'])) {
 			//still available, all good
 
 			return;
@@ -210,31 +175,28 @@ class CleanUp extends TimedJob {
 
 	/**
 	 * gets the offset to fetch users from the mappings table
-	 * @return int
 	 */
-	private function getOffset() {
-		return (int)$this->ocConfig->getAppValue('user_ldap', 'cleanUpJobOffset', 0);
+	private function getOffset(): int {
+		return (int)$this->ocConfig->getAppValue('user_ldap', 'cleanUpJobOffset', '0');
 	}
 
 	/**
 	 * sets the new offset for the next run
 	 * @param bool $reset whether the offset should be set to 0
 	 */
-	public function setOffset($reset = false) {
+	public function setOffset(bool $reset = false): void {
 		$newOffset = $reset ? 0 :
 			$this->getOffset() + $this->getChunkSize();
-		$this->ocConfig->setAppValue('user_ldap', 'cleanUpJobOffset', $newOffset);
+		$this->ocConfig->setAppValue('user_ldap', 'cleanUpJobOffset', (string)$newOffset);
 	}
 
 	/**
 	 * returns the chunk size (limit in DB speak)
-	 * @return int
 	 */
-	public function getChunkSize() {
-		if($this->limit === null) {
-			$this->limit = (int)$this->ocConfig->getAppValue('user_ldap', 'cleanUpJobChunkSize', 50);
+	public function getChunkSize(): int {
+		if ($this->limit === null) {
+			$this->limit = (int)$this->ocConfig->getAppValue('user_ldap', 'cleanUpJobChunkSize', '50');
 		}
 		return $this->limit;
 	}
-
 }
